
# Zenquotes MCP Server

An MCP Server for the Zenquotes API.

## Supported Integrations

- AgentR
- API Key (Coming Soon)
- OAuth (Coming Soon)

## Tools

This is automatically generated from OpenAPI schema for the Zenquotes API.

## Supported Integrations

This tool can be integrated with any service that supports HTTP requests.

## Tool List

| Tool | Description |
|------|-------------|
| get_quote | Get an inspirational quote from the Zen Quotes API |



## Usage

- Login to AgentR
- Follow the quickstart guide to setup MCP Server for your client
- Visit Apps Store and enable the Zenquotes app
- Restart the MCP Server

### Local Development

- Follow the README to test with the local MCP Server
